@@ -1,7 +1,7 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include "settingsdialog.h"
+#include "settings.h"
 
 #include <QMainWindow>
 
@@ -31,14 +31,20 @@ private:
     QMediaPlayer *player;
     QString url;
     QString icon;
+    QLabel *customLabel;
+    QString customString;
+    int customLabelFontSize;
+    QWidget *widget;
     bool running;
+    bool boolean;
     bool showNotifications;
+    bool showCustomLabel;
     bool saveLog;
     QMaemo5InformationBox *infoBox;
     QPushButton *button;
     QLabel *label;
     int alphaValue;
-    SettingsDialog *settingsDialog;
+    Settings *settingsDialog;
 
 
 signals:
